@@ -7,11 +7,11 @@ __all__ = ["approx"]
 _dispatch = Dispatcher()
 
 
-@_dispatch(object, object)
+@_dispatch
 def approx(x, y, **kw_args):
     approx(B.to_numpy(x), B.to_numpy(y), **kw_args)
 
 
-@_dispatch(B.Numeric, B.Numeric)
-def approx(x, y, **kw_args):
-    assert_allclose(x, y, **kw_args)
+@_dispatch
+def approx(x: B.Numeric, y: B.Numeric, **kw_args):
+    assert_allclose(x, y, **kw_args)
\ No newline at end of file
